"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.gitLsAction = void 0;

var _exec = require("../../cmd/exec");

const modes = ['modified', 'others'];

const gitLsAction = async ({
  root,
  log
}, {
  mode
}) => {
  log.info('Get the list of modified or other files');
  const args = ['ls-files', '--exclude-standard'];

  if (mode === 'all') {
    args.push(...modes.map(v => `--${v}`));
  } else {
    args.push(`--${mode}`);
  }

  const {
    stdout
  } = await (0, _exec.exec)({
    cmd: 'git',
    args,
    cwd: root,
    log
  });
  log.info('Return a list of modified or other files');

  if (stdout.trim() === '') {
    log.debug('No modified or other files were found');
    return [];
  }

  const files = stdout.trim().split('\n');
  log.info(files.map(file => `▸ ${file}`));
  return files;
};

exports.gitLsAction = gitLsAction;