"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.eslintAction = void 0;

var _path = require("path");

var _actionConfigs = require("../../../configs/actionConfigs");

var _exec = require("../../cmd/exec");

var _existFiles = require("../../cmd/existFiles");

const eslintAction = async ({
  root,
  cfg,
  log
}, {
  write,
  files
}) => {
  const configFiles = await (0, _existFiles.existFiles)(_actionConfigs.eslintConfigFiles, root);
  configFiles.push((0, _path.join)(cfg, 'eslintrc.json'));
  const cmd = (0, _path.join)(root, _actionConfigs.eslintCommand);
  const args = [];
  args.push('--color');
  args.push('--max-warnings', '0');
  args.push('--config', configFiles[0]);

  if (write) {
    args.push('--fix');
  } else {
    args.push('--format', 'codeframe');
  }

  if (files) {
    const filteredFiles = files.filter(file => !_actionConfigs.eslintIgnoreFiles.has((0, _path.basename)(file)));

    if (filteredFiles.length === 0) {
      log.info('No files found for eslint');
      return;
    }

    args.push(...filteredFiles);
  } else {
    args.push('--ext', `"${_actionConfigs.eslintExtensions}"`);
    args.push('.');
  }

  log.info('Run eslint');
  await (0, _exec.exec)({
    cmd,
    args,
    cwd: root,
    log
  });
};

exports.eslintAction = eslintAction;