"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.jestAction = void 0;

var _path = require("path");

var _actionConfigs = require("../../../configs/actionConfigs");

var _exec = require("../../cmd/exec");

var _getCoverageFolder = require("../../utils/getCoverageFolder");

var _getFirstExistingFile = require("../../utils/getFirstExistingFile");

const options = ['updateSnapshot', 'runInBand', 'watch', 'verbose'];

const jestAction = async ({
  root,
  ci,
  log
}, props) => {
  const coverageFolder = (0, _getCoverageFolder.getCoverageFolder)(root, props.projects);
  const configFile = await (0, _getFirstExistingFile.getFirstExistingFile)({
    cwd: root,
    files: _actionConfigs.jestConfigFiles
  });
  const cmd = (0, _path.join)(root, _actionConfigs.jestCommand);
  const args = ['--config', configFile, '--colors'];

  if (props.projects.length === 1) {
    args.push('--selectProjects', props.projects[0]);
  } else if (props.projects.length > 1) {
    args.push('--selectProjects', ...props.projects);
  }

  options.forEach(option => {
    if (props[option] === true) {
      args.push(`--${option}`);
    }
  });

  if (!props.runInBand) {
    if (props.watch) {
      args.push('--maxWorkers', '25%');
    } else {
      args.push('--maxWorkers', '50%');
    }
  }

  if (ci) {
    args.push('--ci');
    args.push('--silent');
    args.push('--json');
    args.push('--outputFile', (0, _path.join)(coverageFolder, 'jest-final.json'));
  }

  args.push('--coverage');
  args.push('--coverageDirectory', coverageFolder);
  args.push('--coverageReporters', 'json');
  args.push('--coverageThreshold', '\'{"global":{"statements":0,"branches":0,"functions":0,"lines":0}}\'');

  if (props.watch) {
    args.push('--coverageReporters', 'json-summary');
    args.push('--coverageReporters', 'lcovonly');
    args.push('--coverageReporters', 'html');
  }

  log.info('Run test');
  await (0, _exec.exec)({
    cmd,
    args,
    cwd: root,
    log,
    withInteraction: props.watch,
    withDirectOutput: true
  });
};

exports.jestAction = jestAction;