"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.licensecheckAction = void 0;

var _path = require("path");

var _toolLib = require("@kettil/tool-lib");

var _chalk = require("chalk");

var _licenseCompatibilities = require("../../../configs/licenseCompatibilities");

var _licensePackages = require("../../../configs/licensePackages");

var _licenseDisabledError = require("../../errors/licenseDisabledError");

var _licenseIncompatibleError = require("../../errors/licenseIncompatibleError");

var _getNodeModulePaths = require("../../utils/getNodeModulePaths");

var _getNodePackageInfo = require("../../utils/getNodePackageInfo");

var _isLicenseCompatible = require("../../utils/isLicenseCompatible");

const licensecheckAction = async (argv, {
  path = argv.root,
  ignorePackages = []
}) => {
  const {
    log
  } = argv;
  const projectInfo = await (0, _getNodePackageInfo.getNodePackageInfo)(argv, {
    path,
    ignorePackages: [],
    licensePackages: {}
  });

  if (!projectInfo) {
    throw new Error('Project package data was not found');
  }

  const projectLicense = projectInfo.license;
  const supportedLicenses = Object.keys(_licenseCompatibilities.licenseCompatibilities).sort();
  const compatibleLicences = _licenseCompatibilities.licenseCompatibilities[projectLicense];

  if (!(0, _toolLib.isArray)(compatibleLicences)) {
    const workspaceContext = path === argv.root ? '' : ` for "${(0, _path.basename)(path)}"`;
    throw new _licenseDisabledError.LicenseDisabledError('The project license has no compatibility group', `License verification${workspaceContext} is disabled (${projectLicense} != ${supportedLicenses.join('|')})`);
  }

  log.info('Get the paths of the packages');
  const packagePaths = await (0, _getNodeModulePaths.getNodeModulePaths)(path);
  log.info('Read the license data');
  const packageInfos = await Promise.all(packagePaths.map(packagePath => (0, _getNodePackageInfo.getNodePackageInfo)(argv, {
    path: packagePath,
    ignorePackages,
    licensePackages: _licensePackages.licensePackages
  })));
  log.info('Validation of the license data');
  const licenseCompatibleProps = {
    compatibleLicences: compatibleLicences.map(v => v.toUpperCase()),
    projectLicense
  };
  const incompatibleLicenses = packageInfos.filter(v => v !== undefined).filter(packageInfo => !(0, _isLicenseCompatible.isLicenseCompatible)({ ...licenseCompatibleProps,
    packageInfo
  })).map((data, index) => [`${index + 1}`, data.name, data.license, data.version, data.path]);

  if (incompatibleLicenses.length > 0) {
    incompatibleLicenses.unshift([(0, _chalk.red)('#'), (0, _chalk.red)('Name'), (0, _chalk.red)('License'), (0, _chalk.red)('Version'), (0, _chalk.red)('Path')]);
    throw new _licenseIncompatibleError.LicenseIncompatibleError('Incompatible licenses found', incompatibleLicenses);
  }
};

exports.licensecheckAction = licensecheckAction;