"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.semverAction = void 0;

var _toolLib = require("@kettil/tool-lib");

var _chalk = require("chalk");

var _tableError = require("../../errors/tableError");

var _packageLoad = require("../npm/packageLoad");

var _getInaccurateVersions = require("./utils/getInaccurateVersions");

const keys = ['dependencies', 'devDependencies'];

const semverAction = async (argv, {
  path
}) => {
  const packagesJson = await (0, _packageLoad.npmPackageLoadAction)(argv, {
    path
  });

  if (!(0, _toolLib.isObject)(packagesJson)) {
    throw new Error('The package.json was not found');
  }

  const packages = keys.flatMap(key => (0, _getInaccurateVersions.getInaccurateVersions)(packagesJson[key])).sort((0, _toolLib.compareTransformAsc)(([name]) => name)).map((value, index) => [`${index + 1}`, ...value]);

  if (packages.length > 0) {
    packages.unshift([(0, _chalk.red)('#'), (0, _chalk.red)('Package'), (0, _chalk.red)('Version'), (0, _chalk.red)('Expected')]);
    throw new _tableError.TableError('Packages with inaccurate version found', packages);
  }
};

exports.semverAction = semverAction;