"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.spinnerBreak = exports.spinnerWatchAction = exports.spinnerAction = exports.isSpinning = void 0;

var _os = require("os");

var _toolLib = require("@kettil/tool-lib");

var _ora = _interopRequireDefault(require("ora"));

var _exit = require("../cmd/exit");

var _spinnerWarnError = require("../errors/spinnerWarnError");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const instance = (0, _ora.default)({
  color: 'white',
  spinner: 'dots'
});

const isSpinning = () => instance.isSpinning;

exports.isSpinning = isSpinning;

const start = text => {
  instance.start(text);
};

const stop = (key, text) => {
  if (isSpinning()) {
    instance[key](text);
  }
};

const succeed = p => {
  stop('succeed');
  return p;
};

const fail = error => {
  if (error instanceof _spinnerWarnError.SpinnerWarnError) {
    stop('warn', error.spinnerText);
  } else {
    stop('fail');
  }

  throw error;
};

const spinnerAction = (action, text) => {
  start(text);
  return action.then(succeed, fail);
};

exports.spinnerAction = spinnerAction;

const spinnerWatchAction = (actions, spawnKillHandler) => {
  start('Watch-Mode - exit with "q"');
  process.stdin.setRawMode(true);
  process.stdin.setEncoding('utf8');
  process.stdin.resume();
  process.stdin.on('data', key => {
    if (key.toString() === '\u0003') {
      process.stdin.setRawMode(false);
      process.stdin.pause();
      (0, _exit.exit)();
    }

    if (key.toString() === 'q') {
      process.stdin.setRawMode(false);
      process.stdin.pause();
      spawnKillHandler.kill(_os.constants.signals.SIGINT);
    }
  });
  return Promise.all(actions).then(succeed, fail);
};

exports.spinnerWatchAction = spinnerWatchAction;

const spinnerBreak = () => {
  if (isSpinning()) {
    stop('stop');
    return () => instance.start();
  }

  return _toolLib.dummy;
};

exports.spinnerBreak = spinnerBreak;