"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.errorHandler = exports.createHandler = exports.createBuilder = void 0;

var _chalk = require("chalk");

var _access = require("../cmd/access");

var _exit = require("../cmd/exit");

var _messageError = require("../errors/messageError");

var _tableError = require("../errors/tableError");

var _logger = require("./logger");

var _table = require("./table");

const globalOptions = ['root', 'cwd', 'cfg', 'log', 'vvv', 'ci'];

const filterOptions = ([key]) => globalOptions.includes(key);

const filterProps = ([key]) => ![...globalOptions, '_', '$0'].includes(key);

const errorHandler = (msg, error) => {
  if (typeof msg === 'string' && typeof error === 'undefined') {
    (0, _logger.log)(' ');
    (0, _logger.log)(msg);
    (0, _logger.log)(' ');
    (0, _exit.exit)();
  }

  if (error instanceof _tableError.TableError) {
    (0, _logger.log)(' ');
    (0, _logger.log)(`${(0, _chalk.red)('Error')}: ${error.message}`);
    (0, _logger.log)(' ');
    (0, _logger.log)((0, _table.table)(error.list));
    (0, _logger.log)(' ');
    (0, _exit.exit)();
  }

  if (error instanceof _messageError.MessageError) {
    (0, _logger.log)('');
    (0, _logger.log)(error.message);
    (0, _logger.log)('');
    (0, _exit.exit)();
  }

  if (error instanceof Error) {
    (0, _logger.log)('');
    (0, _logger.log)((0, _chalk.red)(error.message));
    (0, _logger.log)('');
  }

  throw error;
};

exports.errorHandler = errorHandler;

const createHandler = task => async argv => {
  const [isReadableRoot, isReadableCwd, isReadableCfg] = await Promise.all([(0, _access.access)(argv.root, 'readable'), (0, _access.access)(argv.cwd, 'readable'), (0, _access.access)(argv.cfg, 'readable')]);

  if (!isReadableRoot) {
    throw new Error(`The folder ${argv.root} is not readable`);
  }

  if (!isReadableCwd) {
    throw new Error(`The folder ${argv.cwd} is not readable`);
  }

  if (!isReadableCfg) {
    throw new Error(`The folder ${argv.cfg} is not readable`);
  }

  argv.log.debug(['Paths:', `▸ root: ${argv.root}`, `▸ cwd:  ${argv.cwd}`, `▸ cfg:  ${argv.cfg}`, '']);
  const options = Object.fromEntries(Object.entries(argv).filter(filterOptions));
  const props = Object.fromEntries(Object.entries(argv).filter(filterProps));
  await task(options, props);
};

exports.createHandler = createHandler;

const createBuilder = (command, callback) => yargs => callback(yargs).usage(`Usage: $0 ${command} [options]`).help().version(false).showHelpOnFail(false);

exports.createBuilder = createBuilder;