"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.exec = void 0;

var _child_process = require("child_process");

var _toolLib = require("@kettil/tool-lib");

var _executableError = require("../errors/executableError");

const exec = ({
  cwd,
  cmd,
  args,
  withInteraction,
  withDirectOutput,
  spawnKillHandler,
  env: envExtend = {},
  log
}) => new Promise((resolve, reject) => {
  const command = `${cmd} ${args.join(' ')}`;
  const env = { ...(0, _toolLib.env)(),
    ...envExtend
  };
  log.info(`\ncwd:  ${cwd}`);
  log.info(`exec: ${command}`);
  let stream;
  let output = '';
  let stdout = '';
  let stderr = '';

  if (withInteraction) {
    stream = (0, _child_process.spawn)(cmd, args, {
      cwd,
      env,
      shell: true,
      stdio: [process.stdin, process.stdout, process.stderr]
    });
  } else {
    stream = (0, _child_process.spawn)(cmd, args, {
      cwd,
      env,
      shell: true
    });

    if (withDirectOutput) {
      stream.stdout.on('data', entry => {
        log.log(String(entry));
      });
      stream.stderr.on('data', entry => {
        log.log(String(entry));
      });
    } else {
      stream.stdout.on('data', data => {
        const value = String(data);
        output += value;
        stdout += value;
        log.debug(value);
      });
      stream.stderr.on('data', data => {
        const value = String(data);
        output += value;
        stderr += value;
        log.debug(value);
      });
    }
  }

  if (spawnKillHandler) {
    spawnKillHandler.addCallback(signal => stream.kill(signal));
  }

  stream.on('close', code => {
    if (typeof code === 'number' && code !== 0) {
      reject(new _executableError.ExecutableError(output, command, code));
    } else {
      resolve({
        stdout,
        stderr,
        output
      });
    }
  });
});

exports.exec = exec;