"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildTask = void 0;

var _packageWorkspaces = require("../actions/npm/packageWorkspaces");

var _babel = require("../actions/tools/babel");

var _spinner = require("../cli/spinner");

var _createSpawnKillHandler = require("../utils/createSpawnKillHandler");

var _hasDependency = require("../utils/hasDependency");

var _taskHook = require("../utils/taskHook");

var _buildBabelTask = require("./subTasks/buildBabelTask");

var _buildTscTask = require("./subTasks/buildTscTask");

const buildTask = async (argv, {
  watch
}) => {
  const workspacePaths = await (0, _packageWorkspaces.npmPackageWorkspacesAction)(argv);
  const hasTypescript = await (0, _hasDependency.hasDependency)(argv, {
    dependency: 'typescript',
    dependencyType: 'devDependencies'
  });
  const paths = workspacePaths.length > 0 ? workspacePaths : [argv.cwd];
  await (0, _taskHook.taskHook)(argv, {
    task: 'build',
    type: 'pre'
  });

  if (watch) {
    if (workspacePaths.length === 0) {
      throw new TypeError('The watch mode is only available in a monorepo, use "npx carna start -w" instead');
    }

    const spawnKillHandler = (0, _createSpawnKillHandler.createSpawnKillHandler)();
    const promises = paths.map(path => (0, _babel.babelAction)({ ...argv,
      cwd: path
    }, {
      watch: true,
      spawnKillHandler
    }));
    await (0, _spinner.spinnerWatchAction)(promises, spawnKillHandler);
  } else {
    if (hasTypescript) {
      await paths.reduce((promise, path) => promise.then((0, _buildTscTask.buildTscTask)({
        argv,
        path
      })), Promise.resolve());
    }

    await paths.reduce((promise, path) => promise.then((0, _buildBabelTask.buildBabelTask)({
      argv,
      path
    })), Promise.resolve());
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'build',
    type: 'post'
  });
};

exports.buildTask = buildTask;