"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.startTask = void 0;

var _os = require("os");

var _path = require("path");

var _toolLib = require("@kettil/tool-lib");

var _actionConfigs = require("../../configs/actionConfigs");

var _packageWorkspaces = require("../actions/npm/packageWorkspaces");

var _babel = require("../actions/tools/babel");

var _babelNode = require("../actions/tools/babelNode");

var _createSpawnKillHandler = require("../utils/createSpawnKillHandler");

var _getFirstExistingFile = require("../utils/getFirstExistingFile");

var _taskHook = require("../utils/taskHook");

var _buildBabelTask = require("./subTasks/buildBabelTask");

const startTask = async (argv, {
  buildDependencies,
  script,
  watch
}) => {
  const workspacePaths = await (0, _packageWorkspaces.npmPackageWorkspacesAction)(argv);
  const props = {
    watch,
    script: await (0, _getFirstExistingFile.getFirstExistingFile)({
      cwd: argv.cwd,
      files: [script, ..._actionConfigs.babelScriptFiles]
    })
  };
  const workspaceFilteredPaths = workspacePaths.filter(path => !props.script.includes(path));
  await (0, _taskHook.taskHook)(argv, {
    task: 'start',
    type: 'pre'
  });

  if (props.watch) {
    const spawnKillHandler = (0, _createSpawnKillHandler.createSpawnKillHandler)();
    const promises = [];

    if (buildDependencies && workspaceFilteredPaths.length > 0) {
      await workspaceFilteredPaths.reduce((promise, path) => promise.then((0, _buildBabelTask.buildBabelTask)({
        argv,
        path
      })), Promise.resolve());
      promises.push(...workspaceFilteredPaths.map(path => (0, _babel.babelAction)({ ...argv,
        cwd: path
      }, {
        watch: true,
        skipInitialBuild: true,
        spawnKillHandler
      })));
      await (0, _toolLib.delay)(250);
    }

    await (0, _babelNode.babelNodeAction)(argv, { ...props,
      watchPaths: workspaceFilteredPaths.map(path => (0, _path.join)(path, 'build'))
    });
    spawnKillHandler.kill(_os.constants.signals.SIGINT);
    await Promise.all(promises);
  } else {
    if (buildDependencies && workspacePaths.length > 0) {
      await workspaceFilteredPaths.reduce((promise, path) => promise.then((0, _buildBabelTask.buildBabelTask)({
        argv,
        path
      })), Promise.resolve());
    }

    await (0, _babelNode.babelNodeAction)(argv, props);
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'start',
    type: 'post'
  });
};

exports.startTask = startTask;