"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.testTask = void 0;

var _toolLib = require("@kettil/tool-lib");

var _coverage = require("../actions/tools/coverage");

var _jest = require("../actions/tools/jest");

var _config = require("../cli/config");

var _spinner = require("../cli/spinner");

var _getTestProjects = require("../utils/getTestProjects");

var _taskHook = require("../utils/taskHook");

var _testHook = require("../utils/testHook");

const transformThreshold = (key, value) => {
  if ((0, _toolLib.isArray)(value) && value.length === 2 && typeof value[0] === 'number' && typeof value[1] === 'number') {
    return [key, value];
  }

  if (typeof value === 'number') {
    return [key, value];
  }

  return [key, undefined];
};

const testTask = async (argv, props) => {
  const configThreshold = await (0, _config.getConfig)(argv.root, 'test.coverage.threshold');
  const coverageThreshold = (0, _toolLib.isObject)(configThreshold) ? (0, _toolLib.objectMap)(configThreshold, transformThreshold) : undefined;
  const projects = await (0, _getTestProjects.getTestProjects)(argv, props.project);
  await (0, _taskHook.taskHook)(argv, {
    task: 'test',
    type: 'pre'
  });

  if (props.watch) {
    try {
      await projects.reduce((promise, project) => promise.then(() => (0, _testHook.testHook)(argv, {
        project,
        type: 'pre'
      })), Promise.resolve());
      await (0, _jest.jestAction)(argv, { ...props,
        projects
      });
    } finally {
      await (0, _toolLib.allSettledSequence)(projects.map(project => () => (0, _testHook.testHook)(argv, {
        project,
        type: 'post'
      })));
    }
  } else {
    try {
      await projects.reduce((promise, project) => promise.then(async () => {
        try {
          await (0, _testHook.testHook)(argv, {
            project,
            type: 'pre'
          });
          await (0, _spinner.spinnerAction)((0, _jest.jestAction)(argv, { ...props,
            projects: [project]
          }), `Test: ${project}`);
        } finally {
          await (0, _testHook.testHook)(argv, {
            project,
            type: 'post'
          });
        }
      }), Promise.resolve());
    } finally {
      await (0, _coverage.coverageAction)(argv, {
        projects,
        watermarks: coverageThreshold
      });
    }
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'test',
    type: 'post'
  });
};

exports.testTask = testTask;