"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFirstExistingFile = void 0;

var _existFiles = require("../cmd/existFiles");

var _firstExistFileError = require("../errors/firstExistFileError");

const getFirstExistingFile = async ({
  cwd,
  files,
  defaultFile
}) => {
  const filteredFiles = files.filter(file => typeof file === 'string');
  const checkedFiles = await (0, _existFiles.existFiles)(filteredFiles, cwd);

  if (checkedFiles.length === 0) {
    if (typeof defaultFile === 'string') {
      return defaultFile;
    }

    throw new _firstExistFileError.FirstExistFileError(`None of the following files were found: ${files.join(', ')}`);
  }

  return checkedFiles[0];
};

exports.getFirstExistingFile = getFirstExistingFile;