"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTestProjects = void 0;

var _toolLib = require("@kettil/tool-lib");

var _actionConfigs = require("../../configs/actionConfigs");

var _exec = require("../cmd/exec");

var _getFirstExistingFile = require("./getFirstExistingFile");

var _sortProjectNames = require("./sortProjectNames");

const getTestProjects = async ({
  cwd,
  log
}, selectedProjects) => {
  const configFile = await (0, _getFirstExistingFile.getFirstExistingFile)({
    cwd,
    files: _actionConfigs.jestConfigFiles
  });
  const args = ['--config', configFile, '--showConfig'];
  const {
    stdout
  } = await (0, _exec.exec)({
    cmd: _actionConfigs.jestCommand,
    args,
    cwd,
    log
  });
  const data = JSON.parse(stdout.trim());
  const projects = (0, _toolLib.isObject)(data) && (0, _toolLib.isArray)(data.configs) ? data.configs.filter(_toolLib.isObject).map(config => (0, _toolLib.isObject)(config.displayName) ? config.displayName.name : config.displayName).filter(name => typeof name === 'string').map(name => name.split(':').reverse().join(':')).sort((0, _sortProjectNames.sortProjectNames)(_actionConfigs.jestPreOrderProjects)).map(name => name.split(':').reverse().join(':')) : [];
  const logProjects = projects.map(name => `▸ ${name}`).join('\n');
  log.info(`Found following test project(s):\n${logProjects}`);

  if (selectedProjects === undefined || selectedProjects.length === 0) {
    return projects;
  }

  const unknownProjects = selectedProjects.filter(v => !projects.includes(v));

  if (unknownProjects.length > 0) {
    throw new Error(`The following test project(s) are unknown: ${unknownProjects.join(', ')}`);
  }

  const runningProjects = projects.filter(v => selectedProjects.includes(v));
  const logRunningProjects = runningProjects.map(name => `▸ ${name}`).join('\n');
  log.info(`Run the following test project(s):\n${logRunningProjects}`);
  return runningProjects;
};

exports.getTestProjects = getTestProjects;